@@ -16,35 +16,47 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.binaryauthorization_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_service_v1_beta1 import (
     pagers,
 )
-from google.cloud.binaryauthorization_v1beta1.types import resources
-from google.cloud.binaryauthorization_v1beta1.types import service
-from google.protobuf import timestamp_pb2  # type: ignore
+from google.cloud.binaryauthorization_v1beta1.types import resources, service
+
+from .client import BinauthzManagementServiceV1Beta1Client
 from .transports.base import (
-    BinauthzManagementServiceV1Beta1Transport,
     DEFAULT_CLIENT_INFO,
+    BinauthzManagementServiceV1Beta1Transport,
 )
 from .transports.grpc_asyncio import (
     BinauthzManagementServiceV1Beta1GrpcAsyncIOTransport,
 )
-from .client import BinauthzManagementServiceV1Beta1Client
 
 
 class BinauthzManagementServiceV1Beta1AsyncClient:
@@ -187,11 +199,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[
             str, BinauthzManagementServiceV1Beta1Transport
         ] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the binauthz management service v1 beta1 client.
@@ -235,11 +247,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def get_policy(
         self,
-        request: Union[service.GetPolicyRequest, dict] = None,
+        request: Optional[Union[service.GetPolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""A [policy][google.cloud.binaryauthorization.v1beta1.Policy]
@@ -258,6 +270,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_get_policy():
@@ -276,7 +295,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.GetPolicy][].
             name (:class:`str`):
@@ -354,11 +373,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def update_policy(
         self,
-        request: Union[service.UpdatePolicyRequest, dict] = None,
+        request: Optional[Union[service.UpdatePolicyRequest, dict]] = None,
         *,
-        policy: resources.Policy = None,
+        policy: Optional[resources.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""Creates or updates a project's
@@ -372,6 +391,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_update_policy():
@@ -394,7 +420,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdatePolicy][].
             policy (:class:`google.cloud.binaryauthorization_v1beta1.types.Policy`):
@@ -477,13 +503,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def create_attestor(
         self,
-        request: Union[service.CreateAttestorRequest, dict] = None,
+        request: Optional[Union[service.CreateAttestorRequest, dict]] = None,
         *,
-        parent: str = None,
-        attestor_id: str = None,
-        attestor: resources.Attestor = None,
+        parent: Optional[str] = None,
+        attestor_id: Optional[str] = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Creates an
@@ -498,6 +524,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_create_attestor():
@@ -522,7 +555,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.CreateAttestor][].
             parent (:class:`str`):
@@ -612,11 +645,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def get_attestor(
         self,
-        request: Union[service.GetAttestorRequest, dict] = None,
+        request: Optional[Union[service.GetAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Gets an
@@ -627,6 +660,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_get_attestor():
@@ -645,7 +685,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.GetAttestor][].
             name (:class:`str`):
@@ -723,11 +763,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def update_attestor(
         self,
-        request: Union[service.UpdateAttestorRequest, dict] = None,
+        request: Optional[Union[service.UpdateAttestorRequest, dict]] = None,
         *,
-        attestor: resources.Attestor = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Updates an
@@ -738,6 +778,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_update_attestor():
@@ -760,7 +807,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdateAttestor][].
             attestor (:class:`google.cloud.binaryauthorization_v1beta1.types.Attestor`):
@@ -843,11 +890,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def list_attestors(
         self,
-        request: Union[service.ListAttestorsRequest, dict] = None,
+        request: Optional[Union[service.ListAttestorsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsAsyncPager:
         r"""Lists
@@ -856,6 +903,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_list_attestors():
@@ -875,7 +929,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.ListAttestors][].
             parent (:class:`str`):
@@ -965,11 +1019,11 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def delete_attestor(
         self,
-        request: Union[service.DeleteAttestorRequest, dict] = None,
+        request: Optional[Union[service.DeleteAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an
@@ -980,6 +1034,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             async def sample_delete_attestor():
@@ -995,7 +1056,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 await client.delete_attestor(request=request)
 
         Args:
-            request (Union[google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.DeleteAttestor][].
             name (:class:`str`):
@@ -1068,14 +1129,9 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-binary-authorization",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BinauthzManagementServiceV1Beta1AsyncClient",)
