@@ -16,33 +16,46 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.binaryauthorization_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_service_v1_beta1 import (
     pagers,
 )
-from google.cloud.binaryauthorization_v1beta1.types import resources
-from google.cloud.binaryauthorization_v1beta1.types import service
-from google.protobuf import timestamp_pb2  # type: ignore
+from google.cloud.binaryauthorization_v1beta1.types import resources, service
+
 from .transports.base import (
-    BinauthzManagementServiceV1Beta1Transport,
     DEFAULT_CLIENT_INFO,
+    BinauthzManagementServiceV1Beta1Transport,
 )
 from .transports.grpc import BinauthzManagementServiceV1Beta1GrpcTransport
 from .transports.grpc_asyncio import (
@@ -68,7 +81,7 @@ class BinauthzManagementServiceV1Beta1ClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[BinauthzManagementServiceV1Beta1Transport]:
         """Returns an appropriate transport class.
 
@@ -362,8 +375,10 @@ class BinauthzManagementServiceV1Beta1Client(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, BinauthzManagementServiceV1Beta1Transport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[
+            Union[str, BinauthzManagementServiceV1Beta1Transport]
+        ] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the binauthz management service v1 beta1 client.
@@ -377,7 +392,7 @@ class BinauthzManagementServiceV1Beta1Client(
             transport (Union[str, BinauthzManagementServiceV1Beta1Transport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -407,6 +422,7 @@ class BinauthzManagementServiceV1Beta1Client(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -459,11 +475,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def get_policy(
         self,
-        request: Union[service.GetPolicyRequest, dict] = None,
+        request: Optional[Union[service.GetPolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""A [policy][google.cloud.binaryauthorization.v1beta1.Policy]
@@ -482,6 +498,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_get_policy():
@@ -568,11 +591,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def update_policy(
         self,
-        request: Union[service.UpdatePolicyRequest, dict] = None,
+        request: Optional[Union[service.UpdatePolicyRequest, dict]] = None,
         *,
-        policy: resources.Policy = None,
+        policy: Optional[resources.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""Creates or updates a project's
@@ -586,6 +609,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_update_policy():
@@ -681,13 +711,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def create_attestor(
         self,
-        request: Union[service.CreateAttestorRequest, dict] = None,
+        request: Optional[Union[service.CreateAttestorRequest, dict]] = None,
         *,
-        parent: str = None,
-        attestor_id: str = None,
-        attestor: resources.Attestor = None,
+        parent: Optional[str] = None,
+        attestor_id: Optional[str] = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Creates an
@@ -702,6 +732,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_create_attestor():
@@ -816,11 +853,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def get_attestor(
         self,
-        request: Union[service.GetAttestorRequest, dict] = None,
+        request: Optional[Union[service.GetAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Gets an
@@ -831,6 +868,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_get_attestor():
@@ -917,11 +961,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def update_attestor(
         self,
-        request: Union[service.UpdateAttestorRequest, dict] = None,
+        request: Optional[Union[service.UpdateAttestorRequest, dict]] = None,
         *,
-        attestor: resources.Attestor = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Updates an
@@ -932,6 +976,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_update_attestor():
@@ -1027,11 +1078,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def list_attestors(
         self,
-        request: Union[service.ListAttestorsRequest, dict] = None,
+        request: Optional[Union[service.ListAttestorsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsPager:
         r"""Lists
@@ -1040,6 +1091,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_list_attestors():
@@ -1139,11 +1197,11 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def delete_attestor(
         self,
-        request: Union[service.DeleteAttestorRequest, dict] = None,
+        request: Optional[Union[service.DeleteAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an
@@ -1154,6 +1212,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1beta1
 
             def sample_delete_attestor():
@@ -1239,14 +1304,9 @@ class BinauthzManagementServiceV1Beta1Client(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-binary-authorization",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BinauthzManagementServiceV1Beta1Client",)
